@@ -1,21 +1,9 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (c) 2007 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "aboutdata.h"
@@ -40,7 +28,6 @@ class KAddressBookApplication : public KontactInterface::PimUniqueApplication
 public:
     KAddressBookApplication(int &argc, char **argv[])
         : KontactInterface::PimUniqueApplication(argc, argv)
-        , mMainWindow(nullptr)
     {
     }
 
@@ -82,7 +69,7 @@ int main(int argc, char **argv)
 
 #ifdef WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
-        KAddressBookUserFeedbackProvider *userFeedBack = new KAddressBookUserFeedbackProvider(nullptr);
+        auto *userFeedBack = new KAddressBookUserFeedbackProvider(nullptr);
         QTextStream(stdout) << userFeedBack->describeDataSources() << '\n';
         delete userFeedBack;
         return 0;
