@@ -1,28 +1,14 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grantleeprintstyle.h"
-#include "kaddressbookimportexportcontactfields.h"
+#include "importexport/contactfields.h"
 #include "printingwizard.h"
 #include "printprogress.h"
-#include "printstyle.h"
-#include <KaddressbookGrantlee/GrantleePrint>
+#include <Akonadi/Contact/GrantleePrint>
 
 #include <KContacts/Addressee>
 
@@ -42,7 +28,7 @@ GrantleePrintStyle::GrantleePrintStyle(const QString &themePath, PrintingWizard
     if (previewFile.exists()) {
         setPreview(previewFile.fileName());
     }
-    setPreferredSortOptions(KAddressBookImportExport::KAddressBookImportExportContactFields::FormattedName, Qt::AscendingOrder);
+    setPreferredSortOptions(KAddressBookImportExport::ContactFields::FormattedName, Qt::AscendingOrder);
 }
 
 GrantleePrintStyle::~GrantleePrintStyle()
@@ -52,7 +38,7 @@ GrantleePrintStyle::~GrantleePrintStyle()
 void GrantleePrintStyle::print(const KContacts::Addressee::List &contacts, PrintProgress *progress)
 {
     QPrinter *printer = wizard()->printer();
-    printer->setPageMargins(20, 20, 20, 20, QPrinter::DevicePixel);
+    printer->setPageMargins(QMarginsF(20, 20, 20, 20), QPageLayout::Point);
 
     progress->addMessage(i18n("Setting up document"));
 
