@@ -1,24 +1,8 @@
 /*
   This file is part of KAddressBook.
-  Copyright (c) 1996-2002 Mirko Boehm <mirko@kde.org>
+  SPDX-FileCopyrightText: 1996-2002 Mirko Boehm <mirko@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "printprogress.h"
@@ -37,7 +21,7 @@ PrintProgress::PrintProgress(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Printing: Progress"));
 
-    QGridLayout *topLayout = new QGridLayout(this);
+    auto *topLayout = new QGridLayout(this);
 
     mLogBrowser = new QTextBrowser(this);
     topLayout->addWidget(mLogBrowser, 0, 0);
