@@ -1,30 +1,14 @@
 /*
   This file is part of KAddressBook.
-  Copyright (c) 1996-2002 Mirko Boehm <mirko@kde.org>
+  SPDX-FileCopyrightText: 1996-2002 Mirko Boehm <mirko@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef PRINTSTYLE_H
 #define PRINTSTYLE_H
 
-#include "kaddressbookimportexportcontactfields.h"
+#include "importexport/contactfields.h"
 
 #include <KContacts/Addressee>
 
@@ -110,7 +94,7 @@ public:
     /**
      * Returns the preferred contact field that shall be used for sorting.
      */
-    KAddressBookImportExport::KAddressBookImportExportContactFields::Field preferredSortField() const;
+    KAddressBookImportExport::ContactFields::Field preferredSortField() const;
 
     /**
      * Returns the preferred order that shall be used for sorting.
@@ -135,7 +119,7 @@ protected:
     /**
      * Sets the preferred sort options for this printing style.
      */
-    void setPreferredSortOptions(KAddressBookImportExport::KAddressBookImportExportContactFields::Field,
+    void setPreferredSortOptions(KAddressBookImportExport::ContactFields::Field,
                                  Qt::SortOrder sortOrder = Qt::AscendingOrder);
 
     /**
@@ -159,7 +143,7 @@ private:
     QHash<QWidget *, KPageWidgetItem *> mPageItems;
     QStringList mPageTitles;
 
-    KAddressBookImportExport::KAddressBookImportExportContactFields::Field mSortField;
+    KAddressBookImportExport::ContactFields::Field mSortField;
     Qt::SortOrder mSortOrder;
 };
 
