@@ -1,25 +1,9 @@
 /*
   This file is part of KAddressBook.
-  Copyright (c) 2002 Jost Schenck <jost@schenck.de>
-                2009 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2002 Jost Schenck <jost@schenck.de>
+  SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "ringbinderstyle.h"
@@ -141,7 +125,7 @@ RingBinderPrintStyle::RingBinderPrintStyle(PrintingWizard *parent)
     , mPageAppearance(new RingBinderStyleAppearanceForm(parent))
 {
     setPreview(QStringLiteral("ringbinder-style.png"));
-    setPreferredSortOptions(KAddressBookImportExport::KAddressBookImportExportContactFields::FamilyName, Qt::AscendingOrder);
+    setPreferredSortOptions(KAddressBookImportExport::ContactFields::FamilyName, Qt::AscendingOrder);
 
     addPage(mPageAppearance, i18n("Ring Binder Printing Style - Appearance"));
 
@@ -175,7 +159,7 @@ void RingBinderPrintStyle::print(const KContacts::Addressee::List &contacts, Pri
     config.sync();
 
     QPrinter *printer = wizard()->printer();
-    printer->setPageMargins(50, 20, 0, 50, QPrinter::DevicePixel);
+    printer->setPageMargins(QMarginsF(50, 20, 0, 50), QPageLayout::Point);
 
     progress->addMessage(i18n("Setting up document"));
 
