@@ -1,25 +1,9 @@
 /*
   This file is part of KAddressBook.
-  Copyright (c) 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
-                     Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
+  SPDX-FileCopyrightText: Tobias Koenig <tokoe@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "stylepage.h"
@@ -33,11 +17,13 @@
 #include <QComboBox>
 #include <KLocalizedString>
 
+using namespace KAddressBookImportExport;
+
 // helper method to sort contact fields by field label
-static bool contactFieldsNameLesser(KAddressBookImportExport::KAddressBookImportExportContactFields::Field field, KAddressBookImportExport::KAddressBookImportExportContactFields::Field otherField)
+static bool contactFieldsNameLesser(ContactFields::Field field, ContactFields::Field otherField)
 {
-    return QString::localeAwareCompare(KAddressBookImportExport::KAddressBookImportExportContactFields::label(field),
-                                       KAddressBookImportExport::KAddressBookImportExportContactFields::label(otherField)) < 0;
+    return QString::localeAwareCompare(ContactFields::label(field),
+                                       ContactFields::label(otherField)) < 0;
 }
 
 StylePage::StylePage(QWidget *parent, const QString &name)
@@ -77,7 +63,7 @@ void StylePage::clearStyleNames()
     mStyleCombo->clear();
 }
 
-void StylePage::setSortField(KAddressBookImportExport::KAddressBookImportExportContactFields::Field field)
+void StylePage::setSortField(ContactFields::Field field)
 {
     mFieldCombo->setCurrentIndex(mFields.indexOf(field));
 }
@@ -91,10 +77,10 @@ void StylePage::setSortOrder(Qt::SortOrder sortOrder)
     }
 }
 
-KAddressBookImportExport::KAddressBookImportExportContactFields::Field StylePage::sortField() const
+ContactFields::Field StylePage::sortField() const
 {
     if (mFieldCombo->currentIndex() == -1) {
-        return KAddressBookImportExport::KAddressBookImportExportContactFields::GivenName;
+        return ContactFields::GivenName;
     }
 
     return mFields[ mFieldCombo->currentIndex() ];
@@ -109,15 +95,15 @@ void StylePage::initFieldCombo()
 {
     mFieldCombo->clear();
 
-    mFields = KAddressBookImportExport::KAddressBookImportExportContactFields::allFields();
-    mFields.remove(0);   // remove KAddressBookImportExport::KAddressBookImportExportContactFields::Undefined
+    mFields = ContactFields::allFields();
+    mFields.remove(0);   // remove ContactFields::Undefined
 
     std::sort(mFields.begin(), mFields.end(), contactFieldsNameLesser);
 
-    KAddressBookImportExport::KAddressBookImportExportContactFields::Fields::ConstIterator it;
-    const KAddressBookImportExport::KAddressBookImportExportContactFields::Fields::ConstIterator end(mFields.constEnd());
+    ContactFields::Fields::ConstIterator it;
+    const ContactFields::Fields::ConstIterator end(mFields.constEnd());
     for (it = mFields.constBegin(); it != end; ++it) {
-        mFieldCombo->addItem(KAddressBookImportExport::KAddressBookImportExportContactFields::label(*it));
+        mFieldCombo->addItem(ContactFields::label(*it));
     }
 }
 
@@ -125,7 +111,7 @@ void StylePage::initGUI()
 {
     setWindowTitle(i18nc("@title:window", "Choose Printing Style"));
 
-    QGridLayout *topLayout = new QGridLayout(this);
+    auto *topLayout = new QGridLayout(this);
 
     QLabel *label
         = new QLabel(
@@ -136,7 +122,7 @@ void StylePage::initGUI()
     topLayout->addWidget(label, 0, 0, 1, 2);
 
     QGroupBox *group = new QGroupBox(i18nc("@title:group", "Sorting"), this);
-    QGridLayout *sortLayout = new QGridLayout();
+    auto *sortLayout = new QGridLayout();
     group->setLayout(sortLayout);
     sortLayout->setAlignment(Qt::AlignTop);
 
@@ -169,7 +155,7 @@ void StylePage::initGUI()
     topLayout->addWidget(group, 1, 0);
 
     group = new QGroupBox(i18nc("@title:group", "Print Style"), this);
-    QVBoxLayout *styleLayout = new QVBoxLayout();
+    auto *styleLayout = new QVBoxLayout();
     group->setLayout(styleLayout);
 
     mStyleCombo = new QComboBox(group);
