@@ -1,34 +1,17 @@
 /*
   This file is part of KAddressBook.
-  Copyright (c) 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
-                     Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
+  SPDX-FileCopyrightText: Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef STYLEPAGE_H
 #define STYLEPAGE_H
 
 #include <QWidget>
-#include "kaddressbookimportexportcontactfields.h"
+#include "importexport/contactfields.h"
 
 class QLabel;
 class QPixmap;
@@ -61,12 +44,12 @@ public:
     /**
      * Set the sort criterion field.
      */
-    void setSortField(KAddressBookImportExport::KAddressBookImportExportContactFields::Field field);
+    void setSortField(KAddressBookImportExport::ContactFields::Field field);
 
     /**
      * Returns the sort criterion field.
      */
-    KAddressBookImportExport::KAddressBookImportExportContactFields::Field sortField() const;
+    KAddressBookImportExport::ContactFields::Field sortField() const;
 
     /**
      * Sets the sort order.
@@ -104,7 +87,7 @@ private:
     QComboBox *mStyleCombo = nullptr;
     QLabel *mPreview = nullptr;
 
-    KAddressBookImportExport::KAddressBookImportExportContactFields::Fields mFields;
+    KAddressBookImportExport::ContactFields::Fields mFields;
 };
 
 #endif // STYLEPAGE_H
